@@ -3,9 +3,9 @@ package Number::ZipCode::JP::Table::Company;
 use strict;
 use warnings;
 
-our $VERSION = '0.20241227';
+our $VERSION = '0.20250131';
 
-# Table last modified: 2024-12-27
+# Table last modified: 2025-01-31
 our %ZIP_TABLE = (
     '001' => '(?:8(?:5(?:[0-2]1|55|77|88)|612))',
     '002' => '(?:850[1-4])',
@@ -63,7 +63,7 @@ our %ZIP_TABLE = (
     '057' => '(?:85(?:11|58))',
     '058' => '(?:(?:0292|8501))',
     '059' => '(?:(?:1(?:39[2-6]|59[2-6]|69[23]|292)|0(?:59[2568]|99[3578]|49[236])|2(?:[14]92|598)|8[67]01|3195))',
-    '060' => '(?:8(?:5(?:[38]\d|4[1-9]|[12][0-35-9]|6[0135-9]|7[02-9]|0[1-68]|5[0-46-9])|6(?:1\d|5[14-68]|8[6-8]|7[016-8]|0[1-9]|6[16-8]|2[1-57-9]|4[0-46-9]|3[0-24-9])|7(?:11|67|9[5-7]|7[146]|0[35-7]|2[15])|406))',
+    '060' => '(?:8(?:5(?:[38]\d|4[1-9]|[12][0-35-9]|6[0135-9]|7[02-9]|0[1-68]|5[0-46-9])|6(?:1\d|5[14-68]|8[6-8]|7[016-8]|0[1-9]|6[16-8]|2[13-57-9]|4[0-46-9]|3[0-24-9])|7(?:11|67|9[5-7]|7[146]|0[35-7]|2[15])|406))',
     '061' => '(?:(?:1(?:39[2-6]|49[236-8]|19[256])|0(?:29[2356]|59[25]|692)|3(?:29[2-6]|197|692)|2292|8501))',
     '062' => '(?:8(?:6(?:86|1[278]|0[1-357-9]|3[0135]|2[24]|4[12]|6[68])|5(?:01|20|7[025]|1[013467]|5[58]|3[029])))',
     '063' => '(?:8(?:5(?:22|0[17]|5[58]|[18][05])|6(?:0[1-36-8]|1[12]|4[15])))',
@@ -105,9 +105,9 @@ our %ZIP_TABLE = (
     '099' => '(?:(?:2(?:19[2-8]|49[235]|392)|1(?:49[2568]|19[78]|595)|3(?:29[23]|69[78])|4(?:19[256]|492)|(?:56|65)92|049[245]))',
     '100' => '(?:(?:8(?:9(?:4[015]|3[0-37]|8[0-3679]|9[46]|2[0-24679]|1[02-9]|6[0-57-9]|0[1-579]|5[0-35689]|7[013-9])|1(?:7[2468]|1[0137-9]|8[124-9]|2[013-8]|0[1-57-9]|6[05689]|4[0-24]|5[0-24589]|3[0-69])|2(?:28|51|70|0[1357]|8[23578]|3[2-5]|1[4-69]|4[156]|6[0258])|3(?:70|5[015]|3[2358]|2[1245]|0[2367]|4[15]|1[01]|8[038])|5(?:11|4[03]|5[058]|6[07]|8[58]|7[57]|2[0-2]|0[235-7])|6(?:55|2[019]|3[19]|6[356]|7[67]|1[07]|0[126]|4[049])|4(?:5[06]|1[015]|2[47]|3[09]|0[235]|[48][48])|0(?:19|5[015]|7[07-9]|8[068]|6[56])|79[1-4])|6(?:1(?:62|7[0-57]|5[0-2])|2(?:55|77|6[02])|0(?:51|66|80)|75[1-6])|149[28]))',
     '101' => '(?:8(?:4(?:1[0568]|6[0-246]|7[057]|4[13-68]|3[0379]|8[05]|0[58]|5[0169]|2[1-59])|6(?:8[28]|0[356]|5[146]|6[57]|2[1246-9]|3[01367]|7[026]|4[235-8]|1[01679])|5(?:3[0-245]|6[1258]|7[59]|4[28]|1[25]|0[249]|8[0569]|2[0-578]|5[24589])|3(?:5[013589]|8[38]|4[367]|0[17-9]|3[3568]|1[0138]|2[3-69]|7[258]|6[267])|7(?:0[137]|1[0-25-8])|9(?:41|50|7[37]|8[36])|2(?:28|0[14]|1[0359])|0(?:11|5[04]|0[128])|1(?:01|89)))',
-    '102' => '(?:8(?:1(?:1[0-357-9]|2[02-58]|8[124-8]|5[0-25]|3[0-289]|0[1-39]|7[0-25-8]|9[0-5]|4[0-24]|6[016])|5(?:0[2-468]|4[013]|5[2-9]|7[01378]|3[0-39]|2[02589]|1[0-3569]|6[013-79]|8[023568])|6(?:3[0-3579]|4[2-5]|2[0-26-8]|8[0589]|7[17-9]|1[0-47-9]|5[0156]|6[06-8]|0[1-4679])|4(?:7[047]|6[0-24-68]|5[0-259]|0[124-7]|4[0158]|2[0146]|8[489]|3[037]|1[01479])|2(?:5[015]|3[0-24-68]|6[045]|8[28]|7[2-57]|2[1-68]|[01][15]|4[016])|3(?:7[0-37]|3[1-36]|2[124]|1[0134]|8[1-38]|6[24]|4[139]|5[0367]|0[1359])|0(?:30|77|8[0-358]|2[256]|5[05]|0[58]|1[125689])|7(?:30|9[58])))',
+    '102' => '(?:8(?:1(?:1[0-357-9]|2[02-58]|8[124-8]|0[239]|5[0-25]|3[0-289]|7[0-25-8]|9[0-5]|4[0-24]|6[016])|5(?:0[2-468]|4[013]|5[2-9]|7[01378]|3[0-39]|2[02589]|1[0-3569]|6[013-79]|8[023568])|6(?:3[0-3579]|4[2-5]|2[0-26-8]|8[0589]|7[17-9]|1[0-47-9]|5[0156]|6[06-8]|0[1-4679])|4(?:7[047]|6[0-24-68]|5[0-259]|0[124-7]|4[0158]|2[0146]|8[489]|3[037]|1[01479])|2(?:5[015]|3[0-24-68]|6[045]|8[28]|7[2-57]|2[1-68]|[01][15]|4[016])|3(?:7[0-37]|3[1-36]|2[124]|1[0134]|8[1-38]|6[24]|4[139]|5[0367]|0[1359])|0(?:30|77|8[0-358]|2[256]|5[05]|0[58]|1[125689])|7(?:30|9[58])))',
     '103' => '(?:8(?:2(?:5[0-2569]|3[0-689]|7[036-8]|0[1-68]|8[2457]|1[0-248]|6[0156]|2[124589]|4[013578])|4(?:7[0-3]|0[1-57]|6[0-24-68]|4[38]|3[0-589]|1[0-79]|2[24-7]|8[02457-9]|5[016])|3(?:70|0[1378]|8[0348]|4[15-7]|1[1-478]|5[0-248]|6[036]|3[01357-9]|2[13-58])|5(?:1[0-257]|5[12468]|7[17]|2[0-25]|0[1-356]|6[67]|8[4-68]|3[4-8]|4[238])|6(?:40|5[0136]|3[169]|7[67]|6[068]|8[0469])|0[01]1))',
-    '104' => '(?:(?:8(?:1(?:2[2-589]|5[018]|6[12578]|4[25]|8[389]|7[014-689]|3[0-589]|1[0-24-8]|0[124589])|3(?:1[023579]|7[07-9]|2[458]|8[013689]|6[35]|5[0167]|3[02358]|4[0-5]|0[12467])|4(?:5[06]|3[013589]|1[369]|0[24578]|8[168]|2[0-469]|6[078]|4[02-49])|5(?:33|77|2[136-8]|4[357]|5[014-689]|6[068]|1[078]|8[1458]|0[1256])|2(?:38|40|71|6[26]|5[124578]|0[568]|8[0-59]|1[0-28])|6(?:14|78|5[06]|8[05]|6[15])|0(?:55|77|1[01]|0[1-37]))|6241))',
+    '104' => '(?:(?:8(?:1(?:2[2-589]|5[018]|6[12578]|8[389]|7[014-689]|4[2578]|3[0-589]|1[0-24-8]|0[124589])|3(?:1[023579]|7[07-9]|2[458]|8[013689]|6[35]|5[0167]|3[02358]|4[0-5]|0[12467])|4(?:5[06]|3[013589]|1[369]|0[24578]|8[168]|2[0-469]|6[078]|4[02-49])|5(?:33|77|2[136-8]|4[357]|5[014-689]|6[068]|1[078]|8[1458]|0[1256])|2(?:38|40|71|6[26]|5[124578]|0[568]|8[0-59]|1[0-28])|6(?:14|78|5[06]|8[05]|6[15])|0(?:55|77|1[01]|0[1-37]))|6241))',
     '105' => '(?:(?:8(?:4(?:7[0-257]|8[2-6]|5[1-36-8]|3[13-7]|[46][014-9]|2[0347-9]|1[0-24-9]|0[1-378])|5(?:6[03578]|1[0-2568]|0[1-357-9]|5[013-8]|8[0-57-9]|7[4-9]|2[1-57-9]|3[0457]|4[03-6])|6(?:7[026-8]|3[04]|8[01569]|6[0568]|1[013-5]|2[0135-7]|5[468]|4[0-24]|0[3468])|3(?:1\d|3[01358]|0[1-9]|2[235])|0(?:10|39|55|0[1258]|7[07]|8[58])|7(?:88|0[127]|1[267]))|7(?:0(?:[58]0|77)|36[05-7]|444)|6[09]50))',
     '106' => '(?:(?:8(?:5(?:6[0-35-79]|0[78]|3[17]|1[458]|7[135-8]|2[12]|5[0-25689]|4[145]|8[0157-9])|6(?:77|4[0-2489]|5[25]|1[16]|6[58]|3[0569]|0[18]|2[0256])|0(?:11|39|0[17])|(?:10|79)7|4(?:01|87))|6(?:1(?:61|88)|06[06])))',
     '107' => '(?:8(?:4(?:20|5[06]|7[127]|0[1-4]|1[126-9]|3[14]|8[24]|4[08]|6[038])|5(?:32|81|0[23578]|7[02]|1[146]|2[0178]|6[037]|5[0268]|4[56])|6(?:01|50|66|1[5-79]|7[46]|3[0-3689]|8[068]|2[0357])|3(?:20|4[0289]|7[013]|8[048]|3[026]|5[125])|0(?:[16]0|77|0[16])))',
@@ -149,7 +149,7 @@ our %ZIP_TABLE = (
     '156' => '(?:8(?:5(?:33|55|88|0[246]|2[02]|1[01])|666))',
     '157' => '(?:85(?:43|50|6[1-35-7]|3[05]|0[18]|2[0-2]|7[0357]|1[01]))',
     '158' => '(?:8(?:5(?:3[1349]|5[0-278]|8[0568]|1[0-48]|6[167]|4[349]|2[0235]|7[578]|0[1-3589])|6(?:40|66|3[0-3]|2[28]|1[05]|0[12])|7[07]1))',
-    '160' => '(?:8(?:4(?:50|72|1[015]|3[03]|2[0239]|6[136]|4[147]|8[4-9]|0[1-37-9])|5(?:65|1[0-2569]|0[1479]|4[37]|8[0-37-9]|2[0-249]|3[05]|7[157])|3(?:21|89|7[3-58]|3[01468]|1[1369]|4[17]|5[1-38]|6[68]|0[1469])|0(?:[01]1|70)|6(?:01|80)|8(?:01|12)|910))',
+    '160' => '(?:8(?:4(?:50|72|1[015]|3[03]|2[0239]|6[136]|4[147]|8[4-9]|0[1-37-9])|3(?:21|89|7[3-58]|3[01468]|1[1369]|4[17]|6[68]|0[1469]|5[1-48])|5(?:65|1[0-2569]|0[1479]|4[37]|8[0-37-9]|2[0-249]|3[05]|7[157])|0(?:[01]1|70)|6(?:01|80)|8(?:01|12)|910))',
     '161' => '(?:8(?:5(?:08|11|75|3[19]|6[057]|5[236-8]|4[0156]|2[0-28])|710))',
     '162' => '(?:8(?:6(?:[78]0|1[24-6]|2[0468]|5[04-6]|[36][689]|4[046]|0[1248])|4(?:33|5[015]|6[04]|4[058]|7[1368]|8[048]|0[27]|2[12]|1[125])|5(?:75|[16][25]|0[235]|3[05]|8[57]|5[16-8]|4[034])|8(?:30|5[03]|0[1-8]|6[01])|0(?:55|60|2[0-2]|0[15])|7(?:0[17]|1[016-8])|953))',
     '163' => '(?:(?:0(?:5(?:5[378]|7[056]|6[0269])|6(?:7[5-7]|5[59]|6[359])|8(?:50|67|3[136])|2(?:78|6[18])|4(?:56|7[18])|9(?:43|3[68])|7[27]7)|1(?:3(?:50|63|71|4[59]|8[28])|0(?:7[13]|6[156]|5[35])|4(?:55|70|88)|5(?:88|3[37]))|8(?:6(?:[28]0|02|3[89]|7[17]|6[016])|0(?:0[13]|8[0-2]|1[29])|5(?:35|48))))',
@@ -239,7 +239,7 @@ our %ZIP_TABLE = (
     '257' => '(?:85(?:[23]3|11|55|66|77|8[458]|0[12]))',
     '258' => '(?:(?:85(?:11|77|85|3[38]|0[16])|0195))',
     '259' => '(?:(?:0(?:1(?:9[2-467]|8[01])|39[2356])|1(?:1(?:8[5-8]|9[236-8])|292)))',
-    '260' => '(?:8(?:6(?:0[13467]|1[0-389]|8[1258]|2[0-24-79]|5[46]|4[2578]|6[0-35-8]|7[0-357]|3[135-7])|5(?:40|7[0257]|5[1257-9]|8[0568]|1[0-35-8]|0[1-35-9]|3[4-68]|6[0-467]|2[13478])|7(?:1[02357]|0[137]|3[34]|2[02])))',
+    '260' => '(?:8(?:6(?:0[13467]|1[0-389]|8[1258]|2[0-24-79]|5[46]|4[2578]|6[0-35-8]|7[0-357]|3[135-7])|5(?:40|7[0257]|5[1257-9]|8[0568]|1[0-35-8]|0[1-35-9]|3[4-68]|6[0-467]|2[13478])|7(?:33|1[02357]|0[137]|2[02])))',
     '261' => '(?:8(?:5(?:1[0-35]|6[0168]|3[0359]|8[0-25-8]|7[57]|5[0248]|0[1-478]|4[145]|2[0-28])|6(?:86|0[1-39])|733))',
     '262' => '(?:8(?:5(?:0[26]|1[0-24])|733))',
     '263' => '(?:8(?:5(?:[12]2|33|77|6[06]|8[58]|5[05]|0[56])|733))',
@@ -369,10 +369,10 @@ our %ZIP_TABLE = (
     '393' => '(?:8(?:5(?:[58]5|11|0[1-3])|601))',
     '394' => '(?:8(?:5(?:[24]0|77|1[0-25]|8[58]|5[05])|6(?:11|65|86)))',
     '395' => '(?:(?:8(?:5(?:[34]3|77|2[028]|5[568]|6[67]|8[58]|0[1-5]|1[15])|6(?:09|11|22|46|55|8[28]))|019[2356]))',
-    '396' => '(?:(?:8(?:5(?:01|85|5[058]|1[01])|6(?:09|82|1[17]))|0293))',
+    '396' => '(?:(?:8(?:5(?:01|77|93|5[058]|8[15]|1[01])|6(?:09|82|1[17]))|0293))',
     '397' => '(?:(?:8(?:5(?:67|71|8[58]|5[05])|60[29])|0[23]92))',
     '398' => '(?:8(?:6(?:86|0[12])|501))',
-    '399' => '(?:(?:8(?:7(?:44|60|0[127]|2[0-258]|5[0145]|1[0-2]|3[0389])|2(?:9[2357]|8[1-3568])|3(?:86|92)|69[56]|192)|4(?:5(?:7[0-35-8]|6[4-8]|8[13-9]|9[2-578])|69[235-7]|39[2-5]|19[25]|498)|0(?:7(?:9[67]|8[1256])|49[235-8]|29[235])|3(?:19[23]|295|797|892)|1(?:392|511|689|895)|9(?:192|393|494)|719[24]|6493))',
+    '399' => '(?:(?:8(?:7(?:44|60|0[127]|2[0-258]|5[0145]|1[0-2]|3[0389])|2(?:9[2357]|8[1-3568])|3(?:86|92)|69[56]|192)|4(?:5(?:6[6-8]|9[24578]|8[3-9]|7[0-268])|69[235-7]|39[2-5]|19[25]|498)|0(?:7(?:9[67]|8[1256])|49[235-8]|29[235])|3(?:19[23]|295|797|892)|1(?:392|511|689|895)|9(?:192|393|494)|719[24]|6493))',
     '400' => '(?:(?:8(?:5(?:2[015]|8[568]|1[0-25]|4[03-5]|7[01578]|5[025689]|0[125689]|6[56]|3[1356])|6(?:01|10|33|6[06])|794)|0(?:2(?:80|9[238])|19[2-6]|49[2358]|39[358]|59[238]|69[235])|159[2-478]))',
     '401' => '(?:(?:0(?:3(?:80|9[5-8])|59[257]|292)|8[56]01))',
     '402' => '(?:85(?:01|55|80))',
@@ -431,7 +431,7 @@ our %ZIP_TABLE = (
     '457' => '(?:8(?:5(?:22|45|77|3[0-35]|5[158]|1[0-25]|6[067]|8[58]|0[18])|71[12]))',
     '458' => '(?:85(?:30|55|8[015]|0[1258]|1[05]|2[0-2]|7[01]))',
     '459' => '(?:85(?:[01]1|22|40))',
-    '460' => '(?:8(?:5(?:5[01589]|2[0-58]|3[0-24-68]|1[0-7]|8[0568]|6[067]|7[578]|0[13-9]|4[15])|6(?:90|7[0-2489]|2[135-8]|0[2568]|6[05-79]|5[01357]|3[0-3578]|1[04-9]|8[1346-9])|4(?:61|7[057]|2[256]|1[125-7]|[08][1-58]|5[0156]|9[01]|4[0457]|3[0-59])|3(?:02|6[06]|2[015]|5[018]|8[38]|3[0138]|1[0-24589])|7(?:20|0[346-8]|1[18])|20[1-4]))',
+    '460' => '(?:8(?:5(?:5[01589]|2[0-58]|3[0-24-68]|1[0-7]|8[0568]|6[067]|7[578]|0[13-9]|4[15])|6(?:90|7[0-2489]|2[135-8]|0[2568]|6[05-79]|5[01357]|3[0-3578]|1[04-9]|8[1346-9])|4(?:61|7[057]|2[256]|1[125-7]|0[2-58]|8[1-58]|5[0156]|9[01]|4[0457]|3[0-59])|3(?:02|6[06]|2[015]|5[018]|8[38]|3[0138]|1[0-24589])|7(?:20|0[346-8]|1[18])|20[1-4]))',
     '461' => '(?:8(?:5(?:41|60|8[0-2568]|2[025]|3[0-249]|0[13-8]|7[57]|1[12]|5[08])|6(?:66|80|4[015]|5[01458]|1[02]|0[235]|3[0169]|2[016]|7[0-3568])|7(?:0[367]|2[159]|9[58]|1[0457])))',
     '462' => '(?:8(?:5(?:2[23]|7[5-7]|5[158]|0[189]|3[05]|1[129]|8[08]|4[035])|666|739))',
     '463' => '(?:85(?:10|5[057]|2[128]|8[05]|6[0157]|7[157]|0[1-35]|3[03568]|4[013578]))',
@@ -518,7 +518,7 @@ our %ZIP_TABLE = (
     '546' => '(?:8501)',
     '547' => '(?:85(?:01|80|1[04]))',
     '549' => '(?:85(?:11|22|85))',
-    '550' => '(?:8(?:5(?:10|27|41|8[05-7]|6[67]|7[0578]|3[08]|0[1-358]|5[0258])|6(?:59|60)))',
+    '550' => '(?:8(?:5(?:27|41|8[05-7]|6[67]|7[0578]|3[08]|0[1-358]|5[0258])|6(?:59|60)))',
     '551' => '(?:85[015]1)',
     '552' => '(?:85(?:01|10))',
     '553' => '(?:8(?:5(?:67|1[1-3]|0[13]|5[0358]|8[58])|739))',
@@ -535,7 +535,7 @@ our %ZIP_TABLE = (
     '564' => '(?:8(?:5(?:23|5[015]|0[13]|6[57]|1[15])|6(?:80|5[01])))',
     '565' => '(?:85(?:11|40|85))',
     '566' => '(?:8(?:5(?:[58]5|01|13|66)|686))',
-    '567' => '(?:8(?:5(?:[34]0|57|2[0135]|8[58]|6[57]|1[015-8]|7[08]|0[1257])|6(?:51|80)))',
+    '567' => '(?:8(?:5(?:[34]0|57|2[0135]|8[58]|6[57]|1[015-8]|7[08]|0[1257])|6(?:[28]0|51)))',
     '569' => '(?:(?:8(?:5(?:33|49|0[135]|5[158]|2[02]|8[58]|7[0157]|6[679]|1[0-2])|6(?:60|86))|1(?:19[2-7]|09[24-68])))',
     '570' => '(?:8(?:5(?:39|40|0[167]|[58][58]|1[15])|6(?:34|66)|787))',
     '571' => '(?:8(?:5(?:[45]5|33|67|71|8[05]|0[2-47])|6(?:[24]0|33|86)))',
@@ -859,11 +859,11 @@ our %ZIP_TABLE = (
     '898' => '(?:8501)',
     '899' => '(?:(?:5(?:19[235]|29[2-4]|69[348]|49[25]|392)|6(?:49[2-5]|19[23]|29[23]|592)|2(?:59[2-6]|[127]92)|4(?:39[2-6]|[12]92)|(?:3[14]|7[146])92|0(?:29[23578]|492)|1(?:395|498|696)|8(?:19[23]|692)))',
     '900' => '(?:8(?:5(?:5\d|2[02457]|8[1568]|4[03-578]|1[02-467]|6[07]|3[013-5]|0[13-5]|7[01578])|6(?:10|66|78|0[1-589]|5[014]|8[68])|7(?:[01]1|35|9[4-7])))',
-    '901' => '(?:(?:2(?:5(?:40|88|97|0[1267]|6[0679]|1[0-25]|5[0-35-9]|2[0156]|3[01])|6(?:86|0[127]|1[01])|7(?:01|10|33)|49[2356]|39[235])|0(?:19[2-467]|49[2-6]|29[245]|39[23]|592)|1(?:19[2356]|39[23]|49[25]|292|595)|3(?:[679]92|19[23]|59[25]|496|895)))',
+    '901' => '(?:(?:2(?:5(?:40|88|97|0[1267]|6[0679]|1[0-25]|5[0-35-9]|2[0156]|3[01])|6(?:86|0[127]|1[01])|7(?:01|10|33|2[05])|49[2356]|39[235])|0(?:19[2-467]|49[2-6]|29[245]|39[23]|592)|1(?:19[2356]|39[23]|49[25]|292|595)|3(?:[679]92|19[23]|59[25]|496|895)))',
     '902' => '(?:85(?:21|1[0-3]|8[58]|5[05]|7[01]))',
     '903' => '(?:(?:02(?:20|1[013-578]|0[13-7])|860[1-3]))',
     '904' => '(?:(?:0(?:49[2-7]|39[2-58]|19[2-5]|29[35])|2(?:19[2-46]|29[2-4]|39[2-4])|8(?:5(?:[01]1|85)|686)|1(?:29[2-4]|[13]92)))',
-    '905' => '(?:(?:0(?:59[2-6]|79[2-6]|[24]92|695)|8(?:5(?:01|12|40|85)|6(?:11|68))|1(?:[23]92|495)|2192))',
+    '905' => '(?:(?:0(?:59[2-6]|79[2-6]|49[24]|292|695)|8(?:5(?:01|12|40|85)|6(?:11|68))|1(?:[23]92|495)|2192))',
     '906' => '(?:(?:8(?:5(?:01|50)|601)|0[256]92))',
     '907' => '(?:(?:850[1-3]|1[28]92))',
     '910' => '(?:(?:8(?:5(?:3[0235-9]|4[0-58]|8\d|0[1-47-9]|5[0-57-9]|1[0-79]|6[0-24-8]|2[0-8]|7[15689])|6(?:22|30|6[056]|0[136]|5[05]|8[068]|7[08]|1[01])|730)|1(?:19[2-5]|29[2-5]|392)|0(?:29[236-8]|39[23])|(?:23|36)92|419[35-8]))',
